@@ -22,7 +22,7 @@ class CardToken(MuviBase):
 
         body = {
             'token': card['id'],
-            'security_code': '999'
+            'security_code': '000' if 'security_code' not in card else card['security_code'],
         }
         self.headers['apikey'] = self.public_key
         r = requests.post(self.url + '/tokens', headers=self.headers, data=json.dumps(body))
