@@ -1,5 +1,4 @@
 import requests
-import json
 import random
 import string
 from iso8601 import parse_date
@@ -92,6 +91,7 @@ class Payment(MuviBase):
                 'id': payment_data['payer']['decidir_id'],
                 'email': payment_data['payer']['email']
             },
+            'site_id':self.site_id_cadena,
             'site_transaction_id': site_transaction_id,
             'token': payment_data['token'],
             'payment_method_id': 1,         # Peso Argentino
@@ -99,11 +99,11 @@ class Payment(MuviBase):
             'currency': 'ARS',
             'payment_type': 'single',
             'establishment_name': self.merchant_name,
-            'sub_payments': []
+            'sub_payments': [],
+            'amount':total_amount, # En cualquier tipo de payment
         }
 
         if 'application_fee' not in payment_data:   # El pago va 100% al hijo
-            body['amount'] = total_amount
             body['site_id'] = self.site_id
             body['installments'] = installments
         else:
@@ -130,7 +130,7 @@ class Payment(MuviBase):
                 body[item] = payment_data[item]
 
         # Se genera la request
-        r = requests.post(self.url + '/payments', headers=self.headers, data=json.dumps(body))
+        r = requests.post(self.url + '/payments', headers=self.headers, json=body)
         response = r.json()
         if r.status_code < 400:
             if 'card' in payment_data:
